@@ -1,7 +1,7 @@
-/* A Bison parser, made from getdate.y, by GNU bison 1.75.  */
+/* A Bison parser, made by GNU Bison 1.875b.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,10 +34,13 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output.  */
-#define YYBISON	1
+#define YYBISON 1
+
+/* Skeleton name.  */
+#define YYSKELETON_NAME "yacc.c"
 
 /* Pure parsers.  */
-#define YYPURE	1
+#define YYPURE 1
 
 /* Using locations.  */
 #define YYLSP_NEEDED 0
@@ -92,7 +95,7 @@
 #line 1 "getdate.y"
 
 /* Parse a string into an internal time stamp.
-   Copyright (C) 1999, 2000, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2002, 2003 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -119,11 +122,10 @@
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
-# ifdef HAVE_ALLOCA_H
-#  include <alloca.h>
-# endif
 #endif
 
+#include <alloca.h>
+
 /* Since the code of getdate.y is not included in the Emacs executable
    itself, there is no need to #define static in this file.  Even if
    the code were included in the Emacs executable, it probably
@@ -267,35 +269,26 @@ static int yylex ();
 # define YYERROR_VERBOSE 0
 #endif
 
-#ifndef YYSTYPE
-#line 172 "getdate.y"
-typedef union {
+#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
+#line 171 "getdate.y"
+typedef union YYSTYPE {
   int intval;
   textint textintval;
-} yystype;
-/* Line 193 of /p/share/bison/yacc.c.  */
-#line 278 "getdate.c"
-# define YYSTYPE yystype
+} YYSTYPE;
+/* Line 191 of yacc.c.  */
+#line 280 "getdate.c"
+# define yystype YYSTYPE /* obsolescent; will be withdrawn */
+# define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
 #endif
 
-#ifndef YYLTYPE
-typedef struct yyltype
-{
-  int first_line;
-  int first_column;
-  int last_line;
-  int last_column;
-} yyltype;
-# define YYLTYPE yyltype
-# define YYLTYPE_IS_TRIVIAL 1
-#endif
+
 
 /* Copy the second part of user declarations.  */
 
 
-/* Line 213 of /p/share/bison/yacc.c.  */
-#line 299 "getdate.c"
+/* Line 214 of yacc.c.  */
+#line 292 "getdate.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -331,7 +324,7 @@ typedef struct yyltype
 
 #if (! defined (yyoverflow) \
      && (! defined (__cplusplus) \
-	 || (YYLTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+	 || (YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -341,13 +334,13 @@ union yyalloc
   };
 
 /* The size of the maximum gap between one aligned stack and the next.  */
-# define YYSTACK_GAP_MAX (sizeof (union yyalloc) - 1)
+# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
 
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
      ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
-      + YYSTACK_GAP_MAX)
+      + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
    not overlap.  */
@@ -361,7 +354,7 @@ union yyalloc
 	{					\
 	  register YYSIZE_T yyi;		\
 	  for (yyi = 0; yyi < (Count); yyi++)	\
-	    (To)[yyi] = (From)[yyi];	\
+	    (To)[yyi] = (From)[yyi];		\
 	}					\
       while (0)
 #  endif
@@ -378,7 +371,7 @@ union yyalloc
 	YYSIZE_T yynewbytes;						\
 	YYCOPY (&yyptr->Stack, Stack, yysize);				\
 	Stack = &yyptr->Stack;						\
-	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAX;	\
+	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
     while (0)
@@ -393,23 +386,24 @@ union yyalloc
 
 /* YYFINAL -- State number of the termination state. */
 #define YYFINAL  2
-#define YYLAST   52
+/* YYLAST -- Last index in YYTABLE.  */
+#define YYLAST   55
 
 /* YYNTOKENS -- Number of terminals. */
 #define YYNTOKENS  22
 /* YYNNTS -- Number of nonterminals. */
 #define YYNNTS  12
 /* YYNRULES -- Number of rules. */
-#define YYNRULES  54
+#define YYNRULES  55
 /* YYNRULES -- Number of states. */
-#define YYNSTATES  64
+#define YYNSTATES  66
 
 /* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   273
 
-#define YYTRANSLATE(X) \
-  ((unsigned)(X) <= YYMAXUTOK ? yytranslate[X] : YYUNDEFTOK)
+#define YYTRANSLATE(YYX)						\
+  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
 static const unsigned char yytranslate[] =
@@ -451,10 +445,10 @@ static const unsigned char yyprhs[] =
 {
        0,     0,     3,     4,     7,     9,    11,    13,    15,    17,
       19,    21,    24,    29,    34,    41,    48,    50,    53,    55,
-      57,    60,    62,    65,    68,    72,    78,    82,    86,    89,
-      94,    97,   101,   104,   106,   109,   112,   114,   117,   120,
-     122,   125,   128,   130,   133,   136,   138,   141,   144,   146,
-     149,   152,   154,   156,   157
+      57,    60,    62,    65,    68,    72,    78,    82,    86,    90,
+      93,    98,   101,   105,   108,   110,   113,   116,   118,   121,
+     124,   126,   129,   132,   134,   137,   140,   142,   145,   148,
+     150,   153,   156,   158,   160,   161
 };
 
 /* YYRHS -- A `-1'-separated list of the rules' RHS. */
@@ -468,25 +462,26 @@ static const yysigned_char yyrhs[] =
        9,     4,    -1,    16,    -1,     7,    -1,    16,     4,    -1,
        5,    -1,     5,    20,    -1,    18,     5,    -1,    18,    21,
       18,    -1,    18,    21,    18,    21,    18,    -1,    18,    17,
-      17,    -1,    18,    12,    17,    -1,    12,    18,    -1,    12,
-      18,    20,    18,    -1,    18,    12,    -1,    18,    12,    18,
-      -1,    31,     3,    -1,    31,    -1,    18,    15,    -1,    17,
-      15,    -1,    15,    -1,    18,    13,    -1,    17,    13,    -1,
-      13,    -1,    18,     6,    -1,    17,     6,    -1,     6,    -1,
-      18,     8,    -1,    17,     8,    -1,     8,    -1,    18,    11,
-      -1,    17,    11,    -1,    11,    -1,    18,    14,    -1,    17,
-      14,    -1,    14,    -1,    18,    -1,    -1,    10,    -1
+      17,    -1,    18,    12,    17,    -1,    12,    17,    17,    -1,
+      12,    18,    -1,    12,    18,    20,    18,    -1,    18,    12,
+      -1,    18,    12,    18,    -1,    31,     3,    -1,    31,    -1,
+      18,    15,    -1,    17,    15,    -1,    15,    -1,    18,    13,
+      -1,    17,    13,    -1,    13,    -1,    18,     6,    -1,    17,
+       6,    -1,     6,    -1,    18,     8,    -1,    17,     8,    -1,
+       8,    -1,    18,    11,    -1,    17,    11,    -1,    11,    -1,
+      18,    14,    -1,    17,    14,    -1,    14,    -1,    18,    -1,
+      -1,    10,    -1
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned short yyrline[] =
 {
-       0,   188,   188,   190,   193,   196,   198,   200,   202,   204,
-     206,   209,   217,   224,   232,   239,   250,   253,   257,   260,
-     262,   266,   272,   277,   284,   290,   310,   317,   325,   330,
-     336,   341,   349,   359,   362,   365,   367,   369,   371,   373,
-     375,   377,   379,   381,   383,   385,   387,   389,   391,   393,
-     395,   397,   401,   437,   440
+       0,   187,   187,   189,   193,   195,   197,   199,   201,   203,
+     205,   209,   216,   223,   231,   238,   250,   252,   257,   259,
+     261,   266,   271,   276,   284,   289,   309,   316,   324,   332,
+     337,   343,   348,   357,   366,   370,   372,   374,   376,   378,
+     380,   382,   384,   386,   388,   390,   392,   394,   396,   398,
+     400,   402,   404,   409,   446,   447
 };
 #endif
 
@@ -521,9 +516,9 @@ static const unsigned char yyr1[] =
        0,    22,    23,    23,    24,    24,    24,    24,    24,    24,
       24,    25,    25,    25,    25,    25,    26,    26,    27,    27,
       27,    28,    28,    28,    29,    29,    29,    29,    29,    29,
-      29,    29,    30,    30,    31,    31,    31,    31,    31,    31,
+      29,    29,    29,    30,    30,    31,    31,    31,    31,    31,
       31,    31,    31,    31,    31,    31,    31,    31,    31,    31,
-      31,    31,    32,    33,    33
+      31,    31,    31,    32,    33,    33
 };
 
 /* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
@@ -531,10 +526,10 @@ static const unsigned char yyr2[] =
 {
        0,     2,     0,     2,     1,     1,     1,     1,     1,     1,
        1,     2,     4,     4,     6,     6,     1,     2,     1,     1,
-       2,     1,     2,     2,     3,     5,     3,     3,     2,     4,
-       2,     3,     2,     1,     2,     2,     1,     2,     2,     1,
-       2,     2,     1,     2,     2,     1,     2,     2,     1,     2,
-       2,     1,     1,     0,     1
+       2,     1,     2,     2,     3,     5,     3,     3,     3,     2,
+       4,     2,     3,     2,     1,     2,     2,     1,     2,     2,
+       1,     2,     2,     1,     2,     2,     1,     2,     2,     1,
+       2,     2,     1,     1,     0,     1
 };
 
 /* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
@@ -542,20 +537,20 @@ static const unsigned char yyr2[] =
    means the default is an error.  */
 static const unsigned char yydefact[] =
 {
-       2,     0,     1,    21,    42,    19,    45,    16,    48,     0,
-      39,    51,    36,    18,     0,    52,     3,     4,     5,     6,
-       8,     7,     9,    33,    10,    22,    17,    28,    20,    41,
-      44,    47,    38,    50,    35,    23,    40,    43,    11,    46,
-      30,    37,    49,    34,     0,     0,     0,    32,     0,    27,
-      31,    26,    53,    24,    29,    54,    13,     0,    12,     0,
-      53,    25,    15,    14
+       2,     0,     1,    21,    43,    19,    46,    16,    49,     0,
+      40,    52,    37,    18,     0,    53,     3,     4,     5,     6,
+       8,     7,     9,    34,    10,    22,    17,     0,    29,    20,
+      42,    45,    48,    39,    51,    36,    23,    41,    44,    11,
+      47,    31,    38,    50,    35,     0,     0,     0,    33,    28,
+       0,    27,    32,    26,    54,    24,    30,    55,    13,     0,
+      12,     0,    54,    25,    15,    14
 };
 
 /* YYDEFGOTO[NTERM-NUM]. */
 static const yysigned_char yydefgoto[] =
 {
       -1,     1,    16,    17,    18,    19,    20,    21,    22,    23,
-      24,    58
+      24,    60
 };
 
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
@@ -563,45 +558,45 @@ static const yysigned_char yydefgoto[] =
 #define YYPACT_NINF -17
 static const yysigned_char yypact[] =
 {
-     -17,     0,   -17,     1,   -17,   -17,   -17,    19,   -17,   -14,
+     -17,     0,   -17,     1,   -17,   -17,   -17,    19,   -17,   -16,
      -17,   -17,   -17,    32,    26,    14,   -17,   -17,   -17,   -17,
-     -17,   -17,   -17,    27,   -17,   -17,   -17,    22,   -17,   -17,
+     -17,   -17,   -17,    27,   -17,   -17,   -17,   -13,    24,   -17,
      -17,   -17,   -17,   -17,   -17,   -17,   -17,   -17,   -17,   -17,
-     -16,   -17,   -17,   -17,    29,    25,    30,   -17,    31,   -17,
-     -17,   -17,    28,    23,   -17,   -17,   -17,    33,   -17,    34,
-      -7,   -17,   -17,   -17
+     -17,    25,   -17,   -17,   -17,    29,    30,    31,   -17,   -17,
+      33,   -17,   -17,   -17,    28,    34,   -17,   -17,   -17,    35,
+     -17,    36,    -7,   -17,   -17,   -17
 };
 
 /* YYPGOTO[NTERM-NUM].  */
 static const yysigned_char yypgoto[] =
 {
      -17,   -17,   -17,   -17,   -17,   -17,   -17,   -17,   -17,   -17,
-     -17,   -10
+     -17,   -12
 };
 
 /* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
    positive, shift that token.  If negative, reduce the rule which
    number is the opposite.  If zero, do what YYDEFACT says.
-   If YYTABLE_NINF, parse error.  */
+   If YYTABLE_NINF, syntax error.  */
 #define YYTABLE_NINF -1
 static const unsigned char yytable[] =
 {
-       2,    49,    50,    55,    27,     3,     4,     5,     6,     7,
-      62,     8,     9,    10,    11,    12,    13,    14,    15,    35,
-      36,    25,    37,    26,    38,    39,    40,    41,    42,    43,
-      47,    44,    29,    45,    30,    46,    28,    31,    55,    32,
-      33,    34,    48,    52,    59,    56,    51,    57,    53,    54,
-      63,    60,    61
+       2,    27,    28,    57,    49,     3,     4,     5,     6,     7,
+      64,     8,     9,    10,    11,    12,    13,    14,    15,    36,
+      37,    25,    38,    26,    39,    40,    41,    42,    43,    44,
+      48,    45,    30,    46,    31,    47,    29,    32,    57,    33,
+      34,    35,    51,    52,    50,    58,    53,    59,    54,    55,
+      65,    56,     0,    62,    63,    61
 };
 
-static const unsigned char yycheck[] =
+static const yysigned_char yycheck[] =
 {
-       0,    17,    18,    10,    18,     5,     6,     7,     8,     9,
+       0,    17,    18,    10,    17,     5,     6,     7,     8,     9,
       17,    11,    12,    13,    14,    15,    16,    17,    18,     5,
        6,    20,     8,     4,    10,    11,    12,    13,    14,    15,
        3,    17,     6,    19,     8,    21,     4,    11,    10,    13,
-      14,    15,    20,    18,    21,    17,    17,    19,    18,    18,
-      60,    18,    18
+      14,    15,    17,    18,    20,    17,    17,    19,    18,    18,
+      62,    18,    -1,    18,    18,    21
 };
 
 /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
@@ -610,11 +605,11 @@ static const unsigned char yystos[] =
 {
        0,    23,     0,     5,     6,     7,     8,     9,    11,    12,
       13,    14,    15,    16,    17,    18,    24,    25,    26,    27,
-      28,    29,    30,    31,    32,    20,     4,    18,     4,     6,
-       8,    11,    13,    14,    15,     5,     6,     8,    10,    11,
-      12,    13,    14,    15,    17,    19,    21,     3,    20,    17,
-      18,    17,    18,    18,    18,    10,    17,    19,    33,    21,
-      18,    18,    17,    33
+      28,    29,    30,    31,    32,    20,     4,    17,    18,     4,
+       6,     8,    11,    13,    14,    15,     5,     6,     8,    10,
+      11,    12,    13,    14,    15,    17,    19,    21,     3,    17,
+      20,    17,    18,    17,    18,    18,    18,    10,    17,    19,
+      33,    21,    18,    18,    17,    33
 };
 
 #if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
@@ -635,13 +630,14 @@ static const unsigned char yystos[] =
 
 #define yyerrok		(yyerrstatus = 0)
 #define yyclearin	(yychar = YYEMPTY)
-#define YYEMPTY		-2
+#define YYEMPTY		(-2)
 #define YYEOF		0
 
 #define YYACCEPT	goto yyacceptlab
 #define YYABORT		goto yyabortlab
 #define YYERROR		goto yyerrlab1
 
+
 /* Like YYERROR except do call yyerror.  This remains here temporarily
    to ease the transition to the new meaning of YYERROR, for GCC.
    Once GCC version 2 has supplanted version 1, this can go.  */
@@ -656,13 +652,13 @@ do								\
     {								\
       yychar = (Token);						\
       yylval = (Value);						\
-      yychar1 = YYTRANSLATE (yychar);				\
+      yytoken = YYTRANSLATE (yychar);				\
       YYPOPSTACK;						\
       goto yybackup;						\
     }								\
   else								\
-    { 								\
-      yyerror ("syntax error: cannot back up");			\
+    {								\
+      yyerror ("syntax error: cannot back up");\
       YYERROR;							\
     }								\
 while (0)
@@ -674,7 +670,7 @@ while (0)
    are run).  */
 
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)           \
+# define YYLLOC_DEFAULT(Current, Rhs, N)         \
   Current.first_line   = Rhs[1].first_line;      \
   Current.first_column = Rhs[1].first_column;    \
   Current.last_line    = Rhs[N].last_line;       \
@@ -684,9 +680,9 @@ while (0)
 /* YYLEX -- calling `yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
-# define YYLEX	yylex (&yylval, YYLEX_PARAM)
+# define YYLEX yylex (&yylval, YYLEX_PARAM)
 #else
-# define YYLEX	yylex (&yylval)
+# define YYLEX yylex (&yylval)
 #endif
 
 /* Enable debugging if requested.  */
@@ -702,19 +698,93 @@ do {						\
   if (yydebug)					\
     YYFPRINTF Args;				\
 } while (0)
+
 # define YYDSYMPRINT(Args)			\
 do {						\
   if (yydebug)					\
     yysymprint Args;				\
 } while (0)
+
+# define YYDSYMPRINTF(Title, Token, Value, Location)		\
+do {								\
+  if (yydebug)							\
+    {								\
+      YYFPRINTF (stderr, "%s ", Title);				\
+      yysymprint (stderr,					\
+                  Token, Value);	\
+      YYFPRINTF (stderr, "\n");					\
+    }								\
+} while (0)
+
+/*------------------------------------------------------------------.
+| yy_stack_print -- Print the state stack from its BOTTOM up to its |
+| TOP (cinluded).                                                   |
+`------------------------------------------------------------------*/
+
+#if defined (__STDC__) || defined (__cplusplus)
+static void
+yy_stack_print (short *bottom, short *top)
+#else
+static void
+yy_stack_print (bottom, top)
+    short *bottom;
+    short *top;
+#endif
+{
+  YYFPRINTF (stderr, "Stack now");
+  for (/* Nothing. */; bottom <= top; ++bottom)
+    YYFPRINTF (stderr, " %d", *bottom);
+  YYFPRINTF (stderr, "\n");
+}
+
+# define YY_STACK_PRINT(Bottom, Top)				\
+do {								\
+  if (yydebug)							\
+    yy_stack_print ((Bottom), (Top));				\
+} while (0)
+
+
+/*------------------------------------------------.
+| Report that the YYRULE is going to be reduced.  |
+`------------------------------------------------*/
+
+#if defined (__STDC__) || defined (__cplusplus)
+static void
+yy_reduce_print (int yyrule)
+#else
+static void
+yy_reduce_print (yyrule)
+    int yyrule;
+#endif
+{
+  int yyi;
+  unsigned int yylno = yyrline[yyrule];
+  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
+             yyrule - 1, yylno);
+  /* Print the symbols being reduced, and their result.  */
+  for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
+    YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
+  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
+}
+
+# define YY_REDUCE_PRINT(Rule)		\
+do {					\
+  if (yydebug)				\
+    yy_reduce_print (Rule);		\
+} while (0)
+
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
 # define YYDSYMPRINT(Args)
+# define YYDSYMPRINTF(Title, Token, Value, Location)
+# define YY_STACK_PRINT(Bottom, Top)
+# define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
 
+
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
 #ifndef	YYINITDEPTH
 # define YYINITDEPTH 200
@@ -793,102 +863,111 @@ yystpcpy (yydest, yysrc)
 
 
 #if YYDEBUG
-/*-----------------------------.
-| Print this symbol on YYOUT.  |
-`-----------------------------*/
+/*--------------------------------.
+| Print this symbol on YYOUTPUT.  |
+`--------------------------------*/
 
-static void
 #if defined (__STDC__) || defined (__cplusplus)
-yysymprint (FILE* yyout, int yytype, YYSTYPE yyvalue)
+static void
+yysymprint (FILE *yyoutput, int yytype, YYSTYPE *yyvaluep)
 #else
-yysymprint (yyout, yytype, yyvalue)
-    FILE* yyout;
+static void
+yysymprint (yyoutput, yytype, yyvaluep)
+    FILE *yyoutput;
     int yytype;
-    YYSTYPE yyvalue;
+    YYSTYPE *yyvaluep;
 #endif
 {
   /* Pacify ``unused variable'' warnings.  */
-  (void) yyvalue;
+  (void) yyvaluep;
 
   if (yytype < YYNTOKENS)
     {
-      YYFPRINTF (yyout, "token %s (", yytname[yytype]);
+      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
 # ifdef YYPRINT
-      YYPRINT (yyout, yytoknum[yytype], yyvalue);
+      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
 # endif
     }
   else
-    YYFPRINTF (yyout, "nterm %s (", yytname[yytype]);
+    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
   switch (yytype)
     {
       default:
         break;
     }
-  YYFPRINTF (yyout, ")");
+  YYFPRINTF (yyoutput, ")");
 }
-#endif /* YYDEBUG. */
-
 
+#endif /* ! YYDEBUG */
 /*-----------------------------------------------.
 | Release the memory associated to this symbol.  |
 `-----------------------------------------------*/
 
-static void
 #if defined (__STDC__) || defined (__cplusplus)
-yydestruct (int yytype, YYSTYPE yyvalue)
+static void
+yydestruct (int yytype, YYSTYPE *yyvaluep)
 #else
-yydestruct (yytype, yyvalue)
+static void
+yydestruct (yytype, yyvaluep)
     int yytype;
-    YYSTYPE yyvalue;
+    YYSTYPE *yyvaluep;
 #endif
 {
   /* Pacify ``unused variable'' warnings.  */
-  (void) yyvalue;
+  (void) yyvaluep;
 
   switch (yytype)
     {
+
       default:
         break;
     }
 }
-
 
 
-/* The user can define YYPARSE_PARAM as the name of an argument to be passed
-   into yyparse.  The argument should have type void *.
-   It should actually point to an object.
-   Grammar actions can access the variable by casting it
-   to the proper pointer type.  */
+/* Prevent warnings from -Wmissing-prototypes.  */
 
 #ifdef YYPARSE_PARAM
 # if defined (__STDC__) || defined (__cplusplus)
-#  define YYPARSE_PARAM_ARG void *YYPARSE_PARAM
-#  define YYPARSE_PARAM_DECL
+int yyparse (void *YYPARSE_PARAM);
 # else
-#  define YYPARSE_PARAM_ARG YYPARSE_PARAM
-#  define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
+int yyparse ();
 # endif
-#else /* !YYPARSE_PARAM */
-# define YYPARSE_PARAM_ARG
-# define YYPARSE_PARAM_DECL
-#endif /* !YYPARSE_PARAM */
-
-/* Prevent warning if -Wstrict-prototypes.  */
-#ifdef __GNUC__
-# ifdef YYPARSE_PARAM
-int yyparse (void *);
-# else
+#else /* ! YYPARSE_PARAM */
+#if defined (__STDC__) || defined (__cplusplus)
 int yyparse (void);
-# endif
+#else
+int yyparse ();
 #endif
+#endif /* ! YYPARSE_PARAM */
 
 
 
 
+
+
+/*----------.
+| yyparse.  |
+`----------*/
+
+#ifdef YYPARSE_PARAM
+# if defined (__STDC__) || defined (__cplusplus)
+int yyparse (void *YYPARSE_PARAM)
+# else
+int yyparse (YYPARSE_PARAM)
+  void *YYPARSE_PARAM;
+# endif
+#else /* ! YYPARSE_PARAM */
+#if defined (__STDC__) || defined (__cplusplus)
 int
-yyparse (YYPARSE_PARAM_ARG)
-     YYPARSE_PARAM_DECL
+yyparse (void)
+#else
+int
+yyparse ()
+
+#endif
+#endif
 {
   /* The lookahead symbol.  */
 int yychar;
@@ -896,7 +975,7 @@ int yychar;
 /* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
-/* Number of parse errors so far.  */
+/* Number of syntax errors so far.  */
 int yynerrs;
 
   register int yystate;
@@ -905,7 +984,7 @@ int yynerrs;
   /* Number of tokens to shift before error messages enabled.  */
   int yyerrstatus;
   /* Lookahead token as an internal (translated) token number.  */
-  int yychar1 = 0;
+  int yytoken = 0;
 
   /* Three stacks and their tools:
      `yyss': related to states,
@@ -969,7 +1048,7 @@ int yynerrs;
  yysetstate:
   *yyssp = yystate;
 
-  if (yyssp >= yyss + yystacksize - 1)
+  if (yyss + yystacksize - 1 <= yyssp)
     {
       /* Get the current used size of the three stacks, in elements.  */
       YYSIZE_T yysize = yyssp - yyss + 1;
@@ -1001,10 +1080,10 @@ int yynerrs;
       goto yyoverflowlab;
 # else
       /* Extend the stack our own way.  */
-      if (yystacksize >= YYMAXDEPTH)
+      if (YYMAXDEPTH <= yystacksize)
 	goto yyoverflowlab;
       yystacksize *= 2;
-      if (yystacksize > YYMAXDEPTH)
+      if (YYMAXDEPTH < yystacksize)
 	yystacksize = YYMAXDEPTH;
 
       {
@@ -1030,7 +1109,7 @@ int yynerrs;
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
-      if (yyssp >= yyss + yystacksize - 1)
+      if (yyss + yystacksize - 1 <= yyssp)
 	YYABORT;
     }
 
@@ -1055,39 +1134,28 @@ yybackup:
 
   /* Not known => get a lookahead token if don't already have one.  */
 
-  /* yychar is either YYEMPTY or YYEOF
-     or a valid token in external form.  */
-
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
       yychar = YYLEX;
     }
 
-  /* Convert token to internal form (in yychar1) for indexing tables with.  */
-
-  if (yychar <= 0)		/* This means end of input.  */
+  if (yychar <= YYEOF)
     {
-      yychar1 = 0;
-      yychar = YYEOF;		/* Don't call YYLEX any more.  */
-
+      yychar = yytoken = YYEOF;
       YYDPRINTF ((stderr, "Now at end of input.\n"));
     }
   else
     {
-      yychar1 = YYTRANSLATE (yychar);
-
-      /* We have to keep this `#if YYDEBUG', since we use variables
-	 which are defined only if `YYDEBUG' is set.  */
-      YYDPRINTF ((stderr, "Next token is "));
-      YYDSYMPRINT ((stderr, yychar1, yylval));
-      YYDPRINTF ((stderr, "\n"));
+      yytoken = YYTRANSLATE (yychar);
+      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
     }
 
-  /* If the proper action on seeing token YYCHAR1 is to reduce or to
+  /* If the proper action on seeing token YYTOKEN is to reduce or to
      detect an error, take that action.  */
-  yyn += yychar1;
-  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yychar1)
+  yyn += yytoken;
+  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
     goto yydefault;
   yyn = yytable[yyn];
   if (yyn <= 0)
@@ -1102,8 +1170,7 @@ yybackup:
     YYACCEPT;
 
   /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %d (%s), ",
-	      yychar, yytname[yychar1]));
+  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));
 
   /* Discard the token being shifted unless it is eof.  */
   if (yychar != YYEOF)
@@ -1149,57 +1216,41 @@ yyreduce:
   yyval = yyvsp[1-yylen];
 
 
-
-#if YYDEBUG
-  /* We have to keep this `#if YYDEBUG', since we use variables which
-     are defined only if `YYDEBUG' is set.  */
-  if (yydebug)
-    {
-      int yyi;
-
-      YYFPRINTF (stderr, "Reducing via rule %d (line %d), ",
-		 yyn - 1, yyrline[yyn]);
-
-      /* Print the symbols being reduced, and their result.  */
-      for (yyi = yyprhs[yyn]; yyrhs[yyi] >= 0; yyi++)
-	YYFPRINTF (stderr, "%s ", yytname[yyrhs[yyi]]);
-      YYFPRINTF (stderr, " -> %s\n", yytname[yyr1[yyn]]);
-    }
-#endif
+  YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
         case 4:
-#line 195 "getdate.y"
+#line 194 "getdate.y"
     { PC.times_seen++; }
     break;
 
   case 5:
-#line 197 "getdate.y"
+#line 196 "getdate.y"
     { PC.local_zones_seen++; }
     break;
 
   case 6:
-#line 199 "getdate.y"
+#line 198 "getdate.y"
     { PC.zones_seen++; }
     break;
 
   case 7:
-#line 201 "getdate.y"
+#line 200 "getdate.y"
     { PC.dates_seen++; }
     break;
 
   case 8:
-#line 203 "getdate.y"
+#line 202 "getdate.y"
     { PC.days_seen++; }
     break;
 
   case 9:
-#line 205 "getdate.y"
+#line 204 "getdate.y"
     { PC.rels_seen++; }
     break;
 
   case 11:
-#line 211 "getdate.y"
+#line 210 "getdate.y"
     {
 	PC.hour = yyvsp[-1].textintval.value;
 	PC.minutes = 0;
@@ -1209,7 +1260,7 @@ yyreduce:
     break;
 
   case 12:
-#line 218 "getdate.y"
+#line 217 "getdate.y"
     {
 	PC.hour = yyvsp[-3].textintval.value;
 	PC.minutes = yyvsp[-1].textintval.value;
@@ -1219,7 +1270,7 @@ yyreduce:
     break;
 
   case 13:
-#line 225 "getdate.y"
+#line 224 "getdate.y"
     {
 	PC.hour = yyvsp[-3].textintval.value;
 	PC.minutes = yyvsp[-1].textintval.value;
@@ -1230,7 +1281,7 @@ yyreduce:
     break;
 
   case 14:
-#line 233 "getdate.y"
+#line 232 "getdate.y"
     {
 	PC.hour = yyvsp[-5].textintval.value;
 	PC.minutes = yyvsp[-3].textintval.value;
@@ -1240,7 +1291,7 @@ yyreduce:
     break;
 
   case 15:
-#line 240 "getdate.y"
+#line 239 "getdate.y"
     {
 	PC.hour = yyvsp[-5].textintval.value;
 	PC.minutes = yyvsp[-3].textintval.value;
@@ -1252,32 +1303,32 @@ yyreduce:
     break;
 
   case 16:
-#line 252 "getdate.y"
+#line 251 "getdate.y"
     { PC.local_isdst = yyvsp[0].intval; }
     break;
 
   case 17:
-#line 254 "getdate.y"
+#line 253 "getdate.y"
     { PC.local_isdst = yyvsp[-1].intval < 0 ? 1 : yyvsp[-1].intval + 1; }
     break;
 
   case 18:
-#line 259 "getdate.y"
+#line 258 "getdate.y"
     { PC.time_zone = yyvsp[0].intval; }
     break;
 
   case 19:
-#line 261 "getdate.y"
+#line 260 "getdate.y"
     { PC.time_zone = yyvsp[0].intval + 60; }
     break;
 
   case 20:
-#line 263 "getdate.y"
+#line 262 "getdate.y"
     { PC.time_zone = yyvsp[-1].intval + 60; }
     break;
 
   case 21:
-#line 268 "getdate.y"
+#line 267 "getdate.y"
     {
 	PC.day_ordinal = 1;
 	PC.day_number = yyvsp[0].intval;
@@ -1285,7 +1336,7 @@ yyreduce:
     break;
 
   case 22:
-#line 273 "getdate.y"
+#line 272 "getdate.y"
     {
 	PC.day_ordinal = 1;
 	PC.day_number = yyvsp[-1].intval;
@@ -1293,7 +1344,7 @@ yyreduce:
     break;
 
   case 23:
-#line 278 "getdate.y"
+#line 277 "getdate.y"
     {
 	PC.day_ordinal = yyvsp[-1].textintval.value;
 	PC.day_number = yyvsp[0].intval;
@@ -1301,7 +1352,7 @@ yyreduce:
     break;
 
   case 24:
-#line 286 "getdate.y"
+#line 285 "getdate.y"
     {
 	PC.month = yyvsp[-2].textintval.value;
 	PC.day = yyvsp[0].textintval.value;
@@ -1309,7 +1360,7 @@ yyreduce:
     break;
 
   case 25:
-#line 291 "getdate.y"
+#line 290 "getdate.y"
     {
 	/* Interpret as YYYY/MM/DD if the first value has 4 or more digits,
 	   otherwise as MM/DD/YY.
@@ -1332,7 +1383,7 @@ yyreduce:
     break;
 
   case 26:
-#line 311 "getdate.y"
+#line 310 "getdate.y"
     {
 	/* ISO 8601 format.  YYYY-MM-DD.  */
 	PC.year = yyvsp[-2].textintval;
@@ -1342,7 +1393,7 @@ yyreduce:
     break;
 
   case 27:
-#line 318 "getdate.y"
+#line 317 "getdate.y"
     {
 	/* e.g. 17-JUN-1992.  */
 	PC.day = yyvsp[-2].textintval.value;
@@ -1353,15 +1404,26 @@ yyreduce:
     break;
 
   case 28:
-#line 326 "getdate.y"
+#line 325 "getdate.y"
+    {
+	/* e.g. JUN-17-1992.  */
+	PC.month = yyvsp[-2].intval;
+	PC.day = -yyvsp[-1].textintval.value;
+	PC.year.value = -yyvsp[0].textintval.value;
+	PC.year.digits = yyvsp[0].textintval.digits;
+      }
+    break;
+
+  case 29:
+#line 333 "getdate.y"
     {
 	PC.month = yyvsp[-1].intval;
 	PC.day = yyvsp[0].textintval.value;
       }
     break;
 
-  case 29:
-#line 331 "getdate.y"
+  case 30:
+#line 338 "getdate.y"
     {
 	PC.month = yyvsp[-3].intval;
 	PC.day = yyvsp[-2].textintval.value;
@@ -1369,16 +1431,16 @@ yyreduce:
       }
     break;
 
-  case 30:
-#line 337 "getdate.y"
+  case 31:
+#line 344 "getdate.y"
     {
 	PC.day = yyvsp[-1].textintval.value;
 	PC.month = yyvsp[0].intval;
       }
     break;
 
-  case 31:
-#line 342 "getdate.y"
+  case 32:
+#line 349 "getdate.y"
     {
 	PC.day = yyvsp[-2].textintval.value;
 	PC.month = yyvsp[-1].intval;
@@ -1386,8 +1448,8 @@ yyreduce:
       }
     break;
 
-  case 32:
-#line 351 "getdate.y"
+  case 33:
+#line 358 "getdate.y"
     {
 	PC.rel_seconds = -PC.rel_seconds;
 	PC.rel_minutes = -PC.rel_minutes;
@@ -1398,98 +1460,98 @@ yyreduce:
       }
     break;
 
-  case 34:
-#line 364 "getdate.y"
-    { PC.rel_year += yyvsp[-1].textintval.value * yyvsp[0].intval; }
-    break;
-
   case 35:
-#line 366 "getdate.y"
+#line 371 "getdate.y"
     { PC.rel_year += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 36:
-#line 368 "getdate.y"
-    { PC.rel_year += yyvsp[0].intval; }
+#line 373 "getdate.y"
+    { PC.rel_year += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 37:
-#line 370 "getdate.y"
-    { PC.rel_month += yyvsp[-1].textintval.value * yyvsp[0].intval; }
+#line 375 "getdate.y"
+    { PC.rel_year += yyvsp[0].intval; }
     break;
 
   case 38:
-#line 372 "getdate.y"
+#line 377 "getdate.y"
     { PC.rel_month += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 39:
-#line 374 "getdate.y"
-    { PC.rel_month += yyvsp[0].intval; }
+#line 379 "getdate.y"
+    { PC.rel_month += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 40:
-#line 376 "getdate.y"
-    { PC.rel_day += yyvsp[-1].textintval.value * yyvsp[0].intval; }
+#line 381 "getdate.y"
+    { PC.rel_month += yyvsp[0].intval; }
     break;
 
   case 41:
-#line 378 "getdate.y"
+#line 383 "getdate.y"
     { PC.rel_day += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 42:
-#line 380 "getdate.y"
-    { PC.rel_day += yyvsp[0].intval; }
+#line 385 "getdate.y"
+    { PC.rel_day += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 43:
-#line 382 "getdate.y"
-    { PC.rel_hour += yyvsp[-1].textintval.value * yyvsp[0].intval; }
+#line 387 "getdate.y"
+    { PC.rel_day += yyvsp[0].intval; }
     break;
 
   case 44:
-#line 384 "getdate.y"
+#line 389 "getdate.y"
     { PC.rel_hour += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 45:
-#line 386 "getdate.y"
-    { PC.rel_hour += yyvsp[0].intval; }
+#line 391 "getdate.y"
+    { PC.rel_hour += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 46:
-#line 388 "getdate.y"
-    { PC.rel_minutes += yyvsp[-1].textintval.value * yyvsp[0].intval; }
+#line 393 "getdate.y"
+    { PC.rel_hour += yyvsp[0].intval; }
     break;
 
   case 47:
-#line 390 "getdate.y"
+#line 395 "getdate.y"
     { PC.rel_minutes += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 48:
-#line 392 "getdate.y"
-    { PC.rel_minutes += yyvsp[0].intval; }
+#line 397 "getdate.y"
+    { PC.rel_minutes += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 49:
-#line 394 "getdate.y"
-    { PC.rel_seconds += yyvsp[-1].textintval.value * yyvsp[0].intval; }
+#line 399 "getdate.y"
+    { PC.rel_minutes += yyvsp[0].intval; }
     break;
 
   case 50:
-#line 396 "getdate.y"
+#line 401 "getdate.y"
     { PC.rel_seconds += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 51:
-#line 398 "getdate.y"
-    { PC.rel_seconds += yyvsp[0].intval; }
+#line 403 "getdate.y"
+    { PC.rel_seconds += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 52:
-#line 403 "getdate.y"
+#line 405 "getdate.y"
+    { PC.rel_seconds += yyvsp[0].intval; }
+    break;
+
+  case 53:
+#line 410 "getdate.y"
     {
 	if (PC.dates_seen
 	    && ! PC.rels_seen && (PC.times_seen || 2 < yyvsp[0].textintval.digits))
@@ -1524,36 +1586,27 @@ yyreduce:
       }
     break;
 
-  case 53:
-#line 439 "getdate.y"
+  case 54:
+#line 446 "getdate.y"
     { yyval.intval = MER24; }
     break;
 
-  case 54:
-#line 441 "getdate.y"
+  case 55:
+#line 448 "getdate.y"
     { yyval.intval = yyvsp[0].intval; }
     break;
 
 
     }
 
-/* Line 1016 of /p/share/bison/yacc.c.  */
-#line 1542 "getdate.c"
+/* Line 999 of yacc.c.  */
+#line 1604 "getdate.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
 
 
-#if YYDEBUG
-  if (yydebug)
-    {
-      short *yyssp1 = yyss - 1;
-      YYFPRINTF (stderr, "state stack now");
-      while (yyssp1 != yyssp)
-	YYFPRINTF (stderr, " %d", *++yyssp1);
-      YYFPRINTF (stderr, "\n");
-    }
-#endif
+  YY_STACK_PRINT (yyss, yyssp);
 
   *++yyvsp = yyval;
 
@@ -1588,55 +1641,63 @@ yyerrlab:
 	{
 	  YYSIZE_T yysize = 0;
 	  int yytype = YYTRANSLATE (yychar);
+	  const char* yyprefix;
 	  char *yymsg;
-	  int yyx, yycount;
+	  int yyx;
 
-	  yycount = 0;
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
-	  for (yyx = yyn < 0 ? -yyn : 0;
-	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
+	  int yyxbegin = yyn < 0 ? -yyn : 0;
+
+	  /* Stay within bounds of both yycheck and yytname.  */
+	  int yychecklim = YYLAST - yyn;
+	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
+	  int yycount = 0;
+
+	  yyprefix = ", expecting ";
+	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
 	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
-	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
-	  yysize += yystrlen ("parse error, unexpected ") + 1;
-	  yysize += yystrlen (yytname[yytype]);
+	      {
+		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
+		yycount += 1;
+		if (yycount == 5)
+		  {
+		    yysize = 0;
+		    break;
+		  }
+	      }
+	  yysize += (sizeof ("syntax error, unexpected ")
+		     + yystrlen (yytname[yytype]));
 	  yymsg = (char *) YYSTACK_ALLOC (yysize);
 	  if (yymsg != 0)
 	    {
-	      char *yyp = yystpcpy (yymsg, "parse error, unexpected ");
+	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
 	      yyp = yystpcpy (yyp, yytname[yytype]);
 
 	      if (yycount < 5)
 		{
-		  yycount = 0;
-		  for (yyx = yyn < 0 ? -yyn : 0;
-		       yyx < (int) (sizeof (yytname) / sizeof (char *));
-		       yyx++)
+		  yyprefix = ", expecting ";
+		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
 		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
 		      {
-			const char *yyq = ! yycount ? ", expecting " : " or ";
-			yyp = yystpcpy (yyp, yyq);
+			yyp = yystpcpy (yyp, yyprefix);
 			yyp = yystpcpy (yyp, yytname[yyx]);
-			yycount++;
+			yyprefix = " or ";
 		      }
 		}
 	      yyerror (yymsg);
 	      YYSTACK_FREE (yymsg);
 	    }
 	  else
-	    yyerror ("parse error; also virtual memory exhausted");
+	    yyerror ("syntax error; also virtual memory exhausted");
 	}
       else
 #endif /* YYERROR_VERBOSE */
-	yyerror ("parse error");
+	yyerror ("syntax error");
     }
-  goto yyerrlab1;
 
 
-/*----------------------------------------------------.
-| yyerrlab1 -- error raised explicitly by an action.  |
-`----------------------------------------------------*/
-yyerrlab1:
+
   if (yyerrstatus == 3)
     {
       /* If just tried and failed to reuse lookahead token after an
@@ -1648,28 +1709,30 @@ yyerrlab1:
 	  /* Pop the error token.  */
           YYPOPSTACK;
 	  /* Pop the rest of the stack.  */
-	  while (yyssp > yyss)
+	  while (yyss < yyssp)
 	    {
-	      YYDPRINTF ((stderr, "Error: popping "));
-	      YYDSYMPRINT ((stderr,
-			    yystos[*yyssp],
-			    *yyvsp));
-	      YYDPRINTF ((stderr, "\n"));
-	      yydestruct (yystos[*yyssp], *yyvsp);
+	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+	      yydestruct (yystos[*yyssp], yyvsp);
 	      YYPOPSTACK;
 	    }
 	  YYABORT;
         }
 
-      YYDPRINTF ((stderr, "Discarding token %d (%s).\n",
-		  yychar, yytname[yychar1]));
-      yydestruct (yychar1, yylval);
+      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
+      yydestruct (yytoken, &yylval);
       yychar = YYEMPTY;
+
     }
 
   /* Else will try to reuse lookahead token after shifting the error
      token.  */
+  goto yyerrlab1;
 
+
+/*----------------------------------------------------.
+| yyerrlab1 -- error raised explicitly by an action.  |
+`----------------------------------------------------*/
+yyerrlab1:
   yyerrstatus = 3;	/* Each real token shifted decrements this.  */
 
   for (;;)
@@ -1690,26 +1753,12 @@ yyerrlab1:
       if (yyssp == yyss)
 	YYABORT;
 
-      YYDPRINTF ((stderr, "Error: popping "));
-      YYDSYMPRINT ((stderr,
-		    yystos[*yyssp], *yyvsp));
-      YYDPRINTF ((stderr, "\n"));
-
-      yydestruct (yystos[yystate], *yyvsp);
+      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+      yydestruct (yystos[yystate], yyvsp);
       yyvsp--;
       yystate = *--yyssp;
 
-
-#if YYDEBUG
-      if (yydebug)
-	{
-	  short *yyssp1 = yyss - 1;
-	  YYFPRINTF (stderr, "Error: state stack now");
-	  while (yyssp1 != yyssp)
-	    YYFPRINTF (stderr, " %d", *++yyssp1);
-	  YYFPRINTF (stderr, "\n");
-	}
-#endif
+      YY_STACK_PRINT (yyss, yyssp);
     }
 
   if (yyn == YYFINAL)
@@ -1757,7 +1806,7 @@ yyreturn:
 }
 
 
-#line 444 "getdate.y"
+#line 451 "getdate.y"
 
 
 /* Include this file down here because bison inserts code above which
