@@ -1,5 +1,5 @@
 /* chown-core.c -- core functions for changing ownership.
-   Copyright (C) 2000, 2002 Free Software Foundation.
+   Copyright (C) 2000, 2002, 2003 Free Software Foundation.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -295,6 +295,8 @@ change_file_owner (int cmdline_arg, const char *file, uid_t uid, gid_t gid,
 		     file and use fchown on the resulting descriptor.  */
 		  int fd = open (file, O_RDONLY | O_NONBLOCK | O_NOCTTY);
 		  fail = (fd == -1 ? 1 : fchown (fd, new_uid, new_gid));
+		  if (fd != -1)
+		    close (fd);
 		}
 	      else
 		{
@@ -330,23 +332,12 @@ change_file_owner (int cmdline_arg, const char *file, uid_t uid, gid_t gid,
 	    }
 	  else
 	    {
-	      /* The change succeeded.  On some systems, the chown function
-		 resets the `special' permission bits.  When run by a
-		 `privileged' user, this program must ensure that at least
-		 the set-uid and set-group ones are still set.  */
-	      if (file_stats.st_mode & ~(S_IFMT | S_IRWXUGO)
-		  /* If we called lchown above (which means this is a symlink),
-		     then skip it.  */
-		  && ! called_lchown)
-		{
-		  if (chmod (file, file_stats.st_mode))
-		    {
-		      error (0, saved_errno,
-			     _("unable to restore permissions of %s"),
-			     quote (file));
-		      fail = 1;
-		    }
-		}
+	      /* The change succeeded.  On some systems (e.g., Linux-2.4.x),
+		 the chown function resets the `special' permission bits.
+		 Do *not* restore those bits;  doing so would open a window in
+		 which a malicious user, M, could subvert a chown command run
+		 by some other user and operating on files in a directory
+		 where M has write access.  */
 	    }
 	}
       else if (chopt->verbosity == V_high)
