@@ -1,5 +1,5 @@
 /* cut - remove parts of lines of files
-   Copyright (C) 1984, 1997, 1998, 1999, 2000, 2001, 2002, 2003 by David M. Ihnat
+   Copyright (C) 1984, 1997-2003 by David M. Ihnat
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -29,9 +29,12 @@
 #include <getopt.h>
 #include <sys/types.h>
 #include "system.h"
-#include "getstr.h"
-#include "closeout.h"
+
 #include "error.h"
+#include "getdelim2.h"
+#include "hash.h"
+#include "quote.h"
+#include "xstrndup.h"
 
 /* The official name of this program (e.g., no `g' prefix).  */
 #define PROGRAM_NAME "cut"
@@ -56,8 +59,7 @@
       if (n_rp >= n_rp_allocated)					\
 	{								\
 	  n_rp_allocated *= 2;						\
-	  (rp) = (struct range_pair *) xrealloc ((char *) (rp),		\
-				   n_rp_allocated * sizeof (*(rp)));	\
+	  (rp) = xrealloc (rp, n_rp_allocated * sizeof (*(rp)));	\
 	}								\
       rp[n_rp].lo = (low);						\
       rp[n_rp].hi = (high);						\
@@ -93,18 +95,15 @@ static unsigned int max_range_endpoint;
    to end of line. */
 static unsigned int eol_range_start;
 
-/* A nonzero, non-1 value with which to distinguish the index
-   corresponding to the lower bound of a range.  */
-#define RANGE_START_SENTINEL 2
-
-/* In byte mode, which bytes to output.
+/* This is a bit vector.
+   In byte mode, which bytes to output.
    In field mode, which DELIM-separated fields to output.
    Both bytes and fields are numbered starting with 1,
-   so the zeroth element of this array is unused.
+   so the zeroth bit of this array is unused.
    A field or byte K has been selected if
-   (K <= MAX_RANGE_ENDPOINT and PRINTABLE_FIELD[K])
+   (K <= MAX_RANGE_ENDPOINT and is_printable_field(K))
     || (EOL_RANGE_START > 0 && K >= EOL_RANGE_START).  */
-static int *printable_field;
+static unsigned char *printable_field;
 
 enum operating_mode
   {
@@ -143,6 +142,15 @@ static char *output_delimiter_string;
 /* Nonzero if we have ever read standard input. */
 static int have_read_stdin;
 
+#define HT_RANGE_START_INDEX_INITIAL_CAPACITY 31
+
+/* The set of range-start indices.  For example, given a range-spec list like
+   `-b1,3-5,4-9,15-', the following indices will be recorded here: 1, 3, 15.
+   Note that although `4' looks like a range-start index, it is in the middle
+   of the `3-5' range, so it doesn't count.
+   This table is created/used IFF output_delimiter_specified is set.  */
+static Hash_table *range_start_ht;
+
 /* For long options that have no equivalent short option, use a
    non-character as a pseudo short option, starting with CHAR_MAX + 1.  */
 enum
@@ -217,6 +225,39 @@ With no FILE, or when FILE is -, read standard input.\n\
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
 
+static inline void
+mark_printable_field (unsigned int i)
+{
+  size_t n = i / CHAR_BIT;
+  printable_field[n] |= (1 << (i % CHAR_BIT));
+}
+
+static inline bool
+is_printable_field (unsigned int i)
+{
+  size_t n = i / CHAR_BIT;
+  return (printable_field[n] >> (i % CHAR_BIT)) & 1;
+}
+
+unsigned int
+hash_int (const void *x, unsigned int tablesize)
+{
+  unsigned int y = (unsigned int) x;
+  return (y % tablesize);
+}
+
+static bool
+hash_compare_ints (void const *x, void const *y)
+{
+  return (x == y) ? true : false;
+}
+
+static bool
+is_range_start_index (int i)
+{
+  return hash_lookup (range_start_ht, (void *) i) ? true : false;
+}
+
 /* Return nonzero if the K'th field or byte is printable.
    When returning nonzero, if RANGE_START is non-NULL,
    set *RANGE_START to nonzero if K is the beginning of a range, and
@@ -232,10 +273,10 @@ print_kth (unsigned int k, int *range_start)
       return 1;
     }
 
-  if (k <= max_range_endpoint && printable_field[k])
+  if (k <= max_range_endpoint && is_printable_field (k))
     {
       if (range_start)
-	*range_start = (printable_field[k] == RANGE_START_SENTINEL);
+	*range_start = is_range_start_index (k);
       return 1;
     }
 
@@ -251,12 +292,15 @@ print_kth (unsigned int k, int *range_start)
    through end of line.  Return nonzero if FIELDSTR contains at least
    one field specification, zero otherwise.  */
 
-/* FIXME-someday:  What if the user wants to cut out the 1,000,000-th field
-   of some huge input file?  This function shouldn't have to allocate a table
-   of a million ints just so we can test every field < 10^6 with an array
-   dereference.  Instead, consider using a dynamic hash table.  It would be
-   simpler and nearly as good a solution to use a 32K x 4-byte table with
-   one bit per field index instead of a whole `int' per index.  */
+/* FIXME-someday:  What if the user wants to cut out the 1,000,000-th
+   field of some huge input file?  This function shouldn't have to
+   allocate a table of a million bits just so we can test every
+   field < 10^6 with an array dereference.  Instead, consider using
+   an adaptive approach: if the range of selected fields is too large,
+   but only a few fields/byte-offsets are actually selected, use a
+   hash table.  If the range of selected fields is too large, and
+   too many are selected, then resort to using the range-pairs (the
+   `rp' array) directly.  */
 
 static int
 set_fields (const char *fieldstr)
@@ -271,10 +315,11 @@ set_fields (const char *fieldstr)
   unsigned int n_rp;
   unsigned int n_rp_allocated;
   unsigned int i;
+  bool in_digits = false;
 
   n_rp = 0;
   n_rp_allocated = 16;
-  rp = (struct range_pair *) xmalloc (n_rp_allocated * sizeof (*rp));
+  rp = xmalloc (n_rp_allocated * sizeof (*rp));
 
   /* Collect and store in RP the range end points.
      It also sets EOL_RANGE_START if appropriate.  */
@@ -283,6 +328,7 @@ set_fields (const char *fieldstr)
     {
       if (*fieldstr == '-')
 	{
+	  in_digits = false;
 	  /* Starting a range. */
 	  if (dash_found)
 	    FATAL_ERROR (_("invalid byte or field list"));
@@ -299,6 +345,7 @@ set_fields (const char *fieldstr)
 	}
       else if (*fieldstr == ',' || ISBLANK (*fieldstr) || *fieldstr == '\0')
 	{
+	  in_digits = false;
 	  /* Ending the string, or this field/byte sublist. */
 	  if (dash_found)
 	    {
@@ -371,8 +418,34 @@ set_fields (const char *fieldstr)
 	}
       else if (ISDIGIT (*fieldstr))
 	{
-	  /* FIXME: detect overflow?  */
-	  value = 10 * value + *fieldstr - '0';
+	  unsigned int new_v;
+	  /* Record beginning of digit string, in case we have to
+	     complain about it.  */
+	  static char const *num_start;
+	  if (!in_digits || !num_start)
+	    num_start = fieldstr;
+	  in_digits = true;
+
+	  /* Detect overflow.  */
+	  new_v = 10 * value + *fieldstr - '0';
+	  if (UINT_MAX / 10 < value || new_v < value * 10)
+	    {
+	      /* In case the user specified -c4294967296-22,
+		 complain only about the first number.  */
+	      /* Determine the length of the offending number.  */
+	      size_t len = strspn (num_start, "0123456789");
+	      char *bad_num = xstrndup (num_start, len);
+	      if (operating_mode == byte_mode)
+		error (0, 0,
+		       _("byte offset %s is too large"), quote (bad_num));
+	      else
+		error (0, 0,
+		       _("field number %s is too large"), quote (bad_num));
+	      free (bad_num);
+	      exit (EXIT_FAILURE);
+	    }
+	  value = new_v;
+
 	  fieldstr++;
 	}
       else
@@ -390,21 +463,41 @@ set_fields (const char *fieldstr)
      the field numbers corresponding to all finite ranges
      (i.e. `2-6' or `-4', but not `5-') in FIELDSTR.  */
 
-  printable_field = (int *) xmalloc ((max_range_endpoint + 1) * sizeof (int));
-  memset (printable_field, 0, (max_range_endpoint + 1) * sizeof (int));
+  printable_field = xcalloc (((max_range_endpoint / CHAR_BIT + 1)
+			      * sizeof (*printable_field)), 1);
 
   /* Set the array entries corresponding to integers in the ranges of RP.  */
   for (i = 0; i < n_rp; i++)
     {
-      unsigned int j = rp[i].lo;
-
-      /* Mark the first position of field or range with a sentinel,
-	 but not if it's already part of another range.  */
-      if (j <= rp[i].hi && ! printable_field[j])
-	printable_field[j] = RANGE_START_SENTINEL;
-      for (++j; j <= rp[i].hi; j++)
+      unsigned int j;
+      for (j = rp[i].lo; j <= rp[i].hi; j++)
 	{
-	  printable_field[j] = 1;
+	  mark_printable_field (j);
+	}
+    }
+
+  if (output_delimiter_specified)
+    {
+      /* Record the range-start indices.  */
+      for (i = 0; i < n_rp; i++)
+	{
+	  unsigned int j = rp[i].lo;
+	  for (j = rp[i].lo; j <= rp[i].hi; j++)
+	    {
+	      if (0 < j && is_printable_field (j)
+		  && !is_printable_field (j - 1))
+		{
+		  /* Record the fact that `j' is a range-start index.  */
+		  void *ent_from_table = hash_insert (range_start_ht,
+						      (void*) j);
+		  if (ent_from_table == NULL)
+		    {
+		      /* Insertion failed due to lack of memory.  */
+		      xalloc_die ();
+		    }
+		  assert ((unsigned int) ent_from_table == j);
+		}
+	    }
 	}
     }
 
@@ -446,9 +539,10 @@ cut_bytes (FILE *stream)
       else
 	{
 	  int range_start;
-	  if (print_kth (++byte_idx, &range_start))
+	  int *rs = output_delimiter_specified ? &range_start : NULL;
+	  if (print_kth (++byte_idx, rs))
 	    {
-	      if (range_start && print_delimiter && output_delimiter_specified)
+	      if (rs && *rs && print_delimiter)
 		{
 		  fwrite (output_delimiter_string, sizeof (char),
 			  output_delimiter_length, stdout);
@@ -494,8 +588,8 @@ cut_fields (FILE *stream)
 	  int len;
 	  size_t n_bytes;
 
-	  len = getstr (&field_1_buffer, &field_1_bufsize, stream,
-			delim, '\n', 0);
+	  len = getdelim2 (&field_1_buffer, &field_1_bufsize, stream,
+			   delim, '\n', 0);
 	  if (len < 0)
 	    {
 	      if (ferror (stream) || feof (stream))
@@ -637,7 +731,9 @@ main (int argc, char **argv)
 {
   int optc, exit_status = 0;
   int delim_specified = 0;
+  char *spec_list_string IF_LINT(= NULL);
 
+  initialize_main (&argc, &argv);
   program_name = argv[0];
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
@@ -666,8 +762,7 @@ main (int argc, char **argv)
 	  if (operating_mode != undefined_mode)
 	    FATAL_ERROR (_("only one type of list may be specified"));
 	  operating_mode = byte_mode;
-	  if (set_fields (optarg) == 0)
-	    FATAL_ERROR (_("missing list of positions"));
+	  spec_list_string = optarg;
 	  break;
 
 	case 'f':
@@ -675,8 +770,7 @@ main (int argc, char **argv)
 	  if (operating_mode != undefined_mode)
 	    FATAL_ERROR (_("only one type of list may be specified"));
 	  operating_mode = field_mode;
-	  if (set_fields (optarg) == 0)
-	    FATAL_ERROR (_("missing list of fields"));
+	  spec_list_string = optarg;
 	  break;
 
 	case 'd':
@@ -724,6 +818,24 @@ main (int argc, char **argv)
     FATAL_ERROR (_("suppressing non-delimited lines makes sense\n\
 \tonly when operating on fields"));
 
+  if (output_delimiter_specified)
+    {
+      range_start_ht = hash_initialize (HT_RANGE_START_INDEX_INITIAL_CAPACITY,
+					NULL, hash_int,
+					hash_compare_ints, NULL);
+      if (range_start_ht == NULL)
+	xalloc_die ();
+
+    }
+
+  if (set_fields (spec_list_string) == 0)
+    {
+      if (operating_mode == field_mode)
+	FATAL_ERROR (_("missing list of fields"));
+      else
+	FATAL_ERROR (_("missing list of positions"));
+    }
+
   if (!delim_specified)
     delim = '\t';
 
@@ -742,6 +854,9 @@ main (int argc, char **argv)
     for (; optind < argc; optind++)
       exit_status |= cut_file (argv[optind]);
 
+  if (range_start_ht)
+    hash_free (range_start_ht);
+
   if (have_read_stdin && fclose (stdin) == EOF)
     {
       error (0, errno, "-");
