@@ -1,5 +1,5 @@
 /* date - print or set the system date and time
-   Copyright (C) 1989-2002 Free Software Foundation, Inc.
+   Copyright (C) 1989-2003 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -27,12 +27,14 @@
 
 #include "system.h"
 #include "argmatch.h"
-#include "closeout.h"
 #include "error.h"
+#include "exitfail.h"
 #include "getdate.h"
 #include "getline.h"
 #include "posixtm.h"
 #include "posixver.h"
+#include "quote.h"
+#include "strftime.h"
 #include "timespec.h"
 
 /* The official name of this program (e.g., no `g' prefix).  */
@@ -42,10 +44,7 @@
 
 int putenv ();
 
-size_t nstrftime PARAMS ((char *, size_t, char const *,
-			  struct tm const *, int, int));
-
-static void show_date PARAMS ((const char *format, struct timespec when));
+static void show_date (const char *format, struct timespec when);
 
 enum Time_spec
 {
@@ -244,7 +243,7 @@ batch_convert (const char *input_filename, const char *format)
       in_stream = fopen (input_filename, "r");
       if (in_stream == NULL)
 	{
-	  error (EXIT_FAILURE, errno, "`%s'", input_filename);
+	  error (EXIT_FAILURE, errno, "%s", quote (input_filename));
 	}
     }
 
@@ -277,7 +276,7 @@ batch_convert (const char *input_filename, const char *format)
     }
 
   if (fclose (in_stream) == EOF)
-    error (2, errno, "`%s'", input_filename);
+    error (2, errno, "%s", quote (input_filename));
 
   if (line != NULL)
     free (line);
@@ -304,12 +303,13 @@ main (int argc, char **argv)
 			       ? COMMON_SHORT_OPTIONS "I::"
 			       : COMMON_SHORT_OPTIONS "I:");
 
+  initialize_main (&argc, &argv);
   program_name = argv[0];
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 
-  close_stdout_set_status (2);
+  exit_failure = 2;
   atexit (close_stdout);
 
   while ((optc = getopt_long (argc, argv, short_options, long_options, NULL))
@@ -528,7 +528,7 @@ show_date (const char *format, struct timespec when)
     {
       int done;
       out_length += 200;
-      out = (char *) xrealloc (out, out_length);
+      out = xrealloc (out, out_length);
 
       /* Mark the first byte of the buffer so we can detect the case
 	 of nstrftime producing an empty string.  Otherwise, this loop
