@@ -1,5 +1,5 @@
 /* df - summarize free disk space
-   Copyright (C) 91, 1995-2002 Free Software Foundation, Inc.
+   Copyright (C) 91, 1995-2003 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,10 +19,6 @@
    --human-readable and --megabyte options added by lm@sgi.com.
    --si and large file support added by eggert@twinsun.com.  */
 
-#ifdef _AIX
- #pragma alloca
-#endif
-
 #include <config.h>
 #include <stdio.h>
 #include <sys/types.h>
@@ -30,14 +26,17 @@
 #include <assert.h>
 
 #include "system.h"
+#include "canonicalize.h"
 #include "dirname.h"
 #include "error.h"
 #include "fsusage.h"
 #include "human.h"
+#include "inttostr.h"
 #include "mountlist.h"
 #include "path-concat.h"
 #include "quote.h"
 #include "save-cwd.h"
+#include "xgetcwd.h"
 
 /* The official name of this program (e.g., no `g' prefix).  */
 #define PROGRAM_NAME "df"
@@ -45,8 +44,6 @@
 #define AUTHORS \
   N_ ("Torbjorn Granlund, David MacKenzie, Larry McVoy, and Paul Eggert")
 
-char *xgetcwd ();
-
 /* Name this program was run with. */
 char *program_name;
 
@@ -64,9 +61,11 @@ static int show_local_fs;
    command line argument -- even if it's a dummy (automounter) entry.  */
 static int show_listed_fs;
 
-/* If positive, the units to use when printing sizes;
-   if negative, the human-readable base.  */
-static int output_block_size;
+/* Human-readable options for output.  */
+static int human_output_opts;
+
+/* The units to use when printing sizes.  */
+static uintmax_t output_block_size;
 
 /* If nonzero, use the POSIX output format.  */
 static int posix_format;
@@ -144,35 +143,56 @@ static struct option const long_options[] =
 static void
 print_header (void)
 {
-  printf (_("Filesystem "));
+  char buf[MAX (LONGEST_HUMAN_READABLE + 1, INT_BUFSIZE_BOUND (uintmax_t))];
 
   if (print_type)
-    printf (_("   Type"));
+    fputs (_("Filesystem    Type"), stdout);
   else
-    printf ("       ");
+    fputs (_("Filesystem        "), stdout);
 
   if (inode_format)
     printf (_("    Inodes   IUsed   IFree IUse%%"));
-  else if (output_block_size < 0)
+  else if (human_output_opts & human_autoscale)
     {
-      if (output_block_size == -1000)
-	printf (_("     Size   Used  Avail Use%%"));
-      else
+      if (human_output_opts & human_base_1024)
 	printf (_("    Size  Used Avail Use%%"));
+      else
+	printf (_("     Size   Used  Avail Use%%"));
     }
   else if (posix_format)
-    printf (_(" %4d-blocks      Used Available Capacity"), output_block_size);
+    printf (_(" %4s-blocks      Used Available Capacity"),
+	    umaxtostr (output_block_size, buf));
   else
     {
-      char buf[LONGEST_HUMAN_READABLE + 1];
-      char *p = human_readable (output_block_size, buf, 1, -1024);
+      int opts = (human_suppress_point_zero
+		  | human_autoscale | human_SI
+		  | (human_output_opts
+		     & (human_group_digits | human_base_1024 | human_B)));
 
-      /* Replace e.g. "1.0K" by "1K".  */
-      size_t plen = strlen (p);
-      if (3 <= plen && strncmp (p + plen - 3, ".0", 2) == 0)
-	strcpy (p + plen - 3, p + plen - 1);
+      /* Prefer the base that makes the human-readable value more exact,
+	 if there is a difference.  */
 
-      printf (_(" %4s-blocks      Used Available Use%%"), p);
+      uintmax_t q1000 = output_block_size;
+      uintmax_t q1024 = output_block_size;
+      bool divisible_by_1000;
+      bool divisible_by_1024;
+
+      do
+	{
+	  divisible_by_1000 = q1000 % 1000 == 0;  q1000 /= 1000;
+	  divisible_by_1024 = q1024 % 1024 == 0;  q1024 /= 1024;
+	}
+      while (divisible_by_1000 & divisible_by_1024);
+
+      if (divisible_by_1000 < divisible_by_1024)
+	opts |= human_base_1024;
+      if (divisible_by_1024 < divisible_by_1000)
+	opts &= ~human_base_1024;
+      if (! (opts & human_base_1024))
+	opts |= human_B;
+
+      printf (_(" %4s-blocks      Used Available Use%%"),
+	      human_readable (output_block_size, buf, opts, 1, 1));
     }
 
   printf (_(" Mounted on\n"));
@@ -210,23 +230,23 @@ excluded_fstype (const char *fstype)
   return 0;
 }
 
-/* Like human_readable_inexact with a human_ceiling
-   human_inexact_style, except return "-" if the argument is -1, and
-   if NEGATIVE is 1 then N represents a negative number, expressed in
-   two's complement.  */
+/* Like human_readable (N, BUF, human_output_opts, INPUT_UNITS, OUTPUT_UNITS),
+   except:
+
+    - Return "-" if N is -1,
+    - If NEGATIVE is 1 then N represents a negative number,
+      expressed in two's complement.  */
 
 static char const *
 df_readable (int negative, uintmax_t n, char *buf,
-	     int from_block_size, int t_output_block_size)
+	     uintmax_t input_units, uintmax_t output_units)
 {
   if (n == -1)
     return "-";
   else
     {
-      char *p = human_readable_inexact (negative ? - n : n,
-					buf + negative, from_block_size,
-					t_output_block_size,
-					human_ceiling);
+      char *p = human_readable (negative ? -n : n, buf + negative,
+				human_output_opts, input_units, output_units);
       if (negative)
 	*--p = '-';
       return p;
@@ -250,8 +270,8 @@ show_dev (const char *disk, const char *mount_point, const char *fstype,
   char buf[3][LONGEST_HUMAN_READABLE + 2];
   int width;
   int use_width;
-  int input_units;
-  int output_units;
+  uintmax_t input_units;
+  uintmax_t output_units;
   uintmax_t total;
   uintmax_t available;
   int negate_available;
@@ -315,8 +335,7 @@ show_dev (const char *disk, const char *mount_point, const char *fstype,
     {
       width = 7;
       use_width = 5;
-      input_units = 1;
-      output_units = output_block_size < 0 ? output_block_size : 1;
+      input_units = output_units = 1;
       total = fsu.fsu_files;
       available = fsu.fsu_ffree;
       negate_available = 0;
@@ -324,8 +343,12 @@ show_dev (const char *disk, const char *mount_point, const char *fstype,
     }
   else
     {
-      width = output_block_size < 0 ? 5 + (output_block_size == -1000) : 9;
-      use_width = (posix_format && 0 <= output_block_size) ? 8 : 4;
+      width = (human_output_opts & human_autoscale
+	       ? 5 + ! (human_output_opts & human_base_1024)
+	       : 9);
+      use_width = ((posix_format
+		    && ! (human_output_opts & human_autoscale))
+		   ? 8 : 4);
       input_units = fsu.fsu_blocksize;
       output_units = output_block_size;
       total = fsu.fsu_blocks;
@@ -409,27 +432,10 @@ show_dev (const char *disk, const char *mount_point, const char *fstype,
   putchar ('\n');
 }
 
-/* Identify the directory, if any, that device
-   DISK is mounted on, and show its disk usage.  */
-
-static void
-show_disk (const char *disk)
-{
-  struct mount_entry *me;
-
-  for (me = mount_list; me; me = me->me_next)
-    if (STREQ (disk, me->me_devname))
-      {
-	show_dev (me->me_devname, me->me_mountdir, me->me_type,
-		  me->me_dummy, me->me_remote);
-	return;
-      }
-  /* No filesystem is mounted on DISK. */
-  show_dev (disk, (char *) NULL, (char *) NULL, 0, 0);
-}
-
 /* Return the root mountpoint of the filesystem on which FILE exists, in
-   malloced storage.  FILE_STAT should be the result of stating FILE.  */
+   malloced storage.  FILE_STAT should be the result of stating FILE.
+   Give a diagnostic and return NULL if unable to determine the mount point.
+   Exit if unable to restore current working directory.  */
 static char *
 find_mount_point (const char *file, const struct stat *file_stat)
 {
@@ -438,27 +444,41 @@ find_mount_point (const char *file, const struct stat *file_stat)
   char *mp = 0;			/* The malloced mount point path.  */
 
   if (save_cwd (&cwd))
-    return NULL;
+    {
+      error (0, errno, _("cannot get current directory"));
+      return NULL;
+    }
 
   if (S_ISDIR (file_stat->st_mode))
     /* FILE is a directory, so just chdir there directly.  */
     {
       last_stat = *file_stat;
       if (chdir (file) < 0)
-	return NULL;
+	{
+	  error (0, errno, _("cannot change to directory %s"), quote (file));
+	  return NULL;
+	}
     }
   else
-    /* FILE is some other kind of file, we need to use its directory.  */
+    /* FILE is some other kind of file; use its directory.  */
     {
-      char *dir = dir_name (file);
-      int rv = chdir (dir);
-      free (dir);
+      char *xdir = dir_name (file);
+      char *dir;
+      ASSIGN_STRDUPA (dir, xdir);
+      free (xdir);
 
-      if (rv < 0)
-	return NULL;
+      if (chdir (dir) < 0)
+	{
+	  error (0, errno, _("cannot change to directory %s"), quote (dir));
+	  return NULL;
+	}
 
       if (stat (".", &last_stat) < 0)
-	goto done;
+	{
+	  error (0, errno, _("cannot stat current directory (now %s)"),
+		 quote (dir));
+	  goto done;
+	}
     }
 
   /* Now walk up FILE's parents until we find another filesystem or /,
@@ -468,12 +488,18 @@ find_mount_point (const char *file, const struct stat *file_stat)
     {
       struct stat st;
       if (stat ("..", &st) < 0)
-	goto done;
+	{
+	  error (0, errno, _("cannot stat %s"), quote (".."));
+	  goto done;
+	}
       if (st.st_dev != last_stat.st_dev || st.st_ino == last_stat.st_ino)
 	/* cwd is the mount point.  */
 	break;
       if (chdir ("..") < 0)
-	goto done;
+	{
+	  error (0, errno, _("cannot change to directory %s"), quote (".."));
+	  goto done;
+	}
       last_stat = st;
     }
 
@@ -484,8 +510,9 @@ done:
   /* Restore the original cwd.  */
   {
     int save_errno = errno;
-    if (restore_cwd (&cwd, 0, mp))
-      exit (EXIT_FAILURE);			/* We're scrod.  */
+    if (restore_cwd (&cwd))
+      error (EXIT_FAILURE, errno,
+	     _("failed to return to initial working directory"));
     free_cwd (&cwd);
     errno = save_errno;
   }
@@ -493,16 +520,34 @@ done:
   return mp;
 }
 
+/* If DISK corresponds to a mount point, show its usage
+   and return nonzero.  Otherwise, return zero.
+   STATP must be the result of `stat (DISK, STATP)'.  */
+static int
+show_disk (const char *disk, const struct stat *statp)
+{
+  struct mount_entry *me;
+
+  for (me = mount_list; me; me = me->me_next)
+    if (STREQ (disk, me->me_devname))
+      {
+	show_dev (me->me_devname, me->me_mountdir, me->me_type,
+		  me->me_dummy, me->me_remote);
+	return 1;
+      }
+
+  return 0;
+}
+
 /* Figure out which device file or directory POINT is mounted on
    and show its disk usage.
-   STATP is the results of `stat' on POINT.  */
+   STATP must be the result of `stat (POINT, STATP)'.  */
 static void
 show_point (const char *point, const struct stat *statp)
 {
   struct stat disk_stats;
   struct mount_entry *me;
   struct mount_entry *matching_dummy = NULL;
-  char *needs_freeing = NULL;
 
   /* If POINT is an absolute path name, see if we can find the
      mount point without performing any extra stat calls at all.  */
@@ -523,78 +568,14 @@ show_point (const char *point, const struct stat *statp)
 	goto show_matching_dummy;
     }
 
-  /* Ideally, the following mess of #if'd code would be in a separate
-     file, and there'd be a single function call here.  FIXME, someday.  */
-
-#if HAVE_REALPATH || HAVE_RESOLVEPATH || HAVE_CANONICALIZE_FILE_NAME
   /* Calculate the real absolute path for POINT, and use that to find
      the mount point.  This avoids statting unavailable mount points,
      which can hang df.  */
   {
-    char const *abspoint = point;
-    char *resolved;
-    ssize_t resolved_len;
+    char *resolved = canonicalize_file_name (point);
+    ssize_t resolved_len = resolved ? strlen (resolved) : -1;
     struct mount_entry *best_match = NULL;
 
-# if HAVE_CANONICALIZE_FILE_NAME
-    resolved = canonicalize_file_name (abspoint);
-    resolved_len = resolved ? strlen (resolved) : -1;
-# else
-#  if HAVE_RESOLVEPATH
-    /* All known hosts with resolvepath (e.g. Solaris 7) don't turn
-       relative names into absolute ones, so prepend the working
-       directory if the path is not absolute.  */
-
-    if (*point != '/')
-      {
-	static char const *wd;
-
-	if (! wd)
-	  {
-	    struct stat pwd_stats;
-	    struct stat dot_stats;
-
-	    /* Use PWD if it is correct; this is usually cheaper than
-               xgetcwd.  */
-	    wd = getenv ("PWD");
-	    if (! (wd
-		   && stat (wd, &pwd_stats) == 0
-		   && stat (".", &dot_stats) == 0
-		   && SAME_INODE (pwd_stats, dot_stats)))
-	      wd = xgetcwd ();
-	  }
-
-	if (wd)
-	  {
-	    needs_freeing = path_concat (wd, point, NULL);
-	    if (needs_freeing)
-	      abspoint = needs_freeing;
-	  }
-      }
-#  endif
-
-#  if HAVE_RESOLVEPATH
-    {
-      size_t resolved_size = strlen (abspoint);
-      while (1)
-	{
-	  resolved_size = 2 * resolved_size + 1;
-	  resolved = xmalloc (resolved_size);
-	  resolved_len = resolvepath (abspoint, resolved, resolved_size);
-	  if (resolved_len < resolved_size)
-	    break;
-	  free (resolved);
-	}
-    }
-#  else
-    /* Use realpath only as a last resort.
-       It provides a very poor interface.  */
-    resolved = xmalloc (PATH_MAX + 1);
-    resolved = (char *) realpath (abspoint, resolved);
-    resolved_len = resolved ? strlen (resolved) : -1;
-#  endif
-# endif
-
     if (1 <= resolved_len && resolved[0] == '/')
       {
 	size_t best_match_len = 0;
@@ -625,7 +606,6 @@ show_point (const char *point, const struct stat *statp)
 	goto show_me;
       }
   }
-#endif
 
   for (me = mount_list; me; me = me->me_next)
     {
@@ -673,20 +653,15 @@ show_point (const char *point, const struct stat *statp)
 	show_dev (0, mp, 0, 0, 0);
 	free (mp);
       }
-    else
-      error (0, errno, "%s", quote (point));
   }
 
-  goto free_then_return;
+  return;
 
  show_matching_dummy:
   me = matching_dummy;
  show_me:
   show_dev (me->me_devname, me->me_mountdir, me->me_type, me->me_dummy,
 	    me->me_remote);
- free_then_return:
-  if (needs_freeing)
-    free (needs_freeing);
 }
 
 /* Determine what kind of node PATH is and show the disk usage
@@ -695,10 +670,11 @@ show_point (const char *point, const struct stat *statp)
 static void
 show_entry (const char *path, const struct stat *statp)
 {
-  if (S_ISBLK (statp->st_mode) || S_ISCHR (statp->st_mode))
-    show_disk (path);
-  else
-    show_point (path, statp);
+  if ((S_ISBLK (statp->st_mode) || S_ISCHR (statp->st_mode))
+      && show_disk (path, statp))
+    return;
+
+  show_point (path, statp);
 }
 
 /* Show all mounted filesystems, except perhaps those that are of
@@ -721,7 +697,7 @@ add_fs_type (const char *fstype)
 {
   struct fs_type_list *fsp;
 
-  fsp = (struct fs_type_list *) xmalloc (sizeof (struct fs_type_list));
+  fsp = xmalloc (sizeof (struct fs_type_list));
   fsp->fs_name = (char *) fstype;
   fsp->fs_next = fs_select_list;
   fs_select_list = fsp;
@@ -734,7 +710,7 @@ add_excluded_fs_type (const char *fstype)
 {
   struct fs_type_list *fsp;
 
-  fsp = (struct fs_type_list *) xmalloc (sizeof (struct fs_type_list));
+  fsp = xmalloc (sizeof (struct fs_type_list));
   fsp->fs_name = (char *) fstype;
   fsp->fs_next = fs_exclude_list;
   fs_exclude_list = fsp;
@@ -781,7 +757,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
       fputs (VERSION_OPTION_DESCRIPTION, stdout);
       fputs (_("\n\
 SIZE may be (or may be an integer optionally followed by) one of following:\n\
-kB 1000, K 1024, MB 1,000,000, M 1,048,576, and so on for G, T, P, E, Z, Y.\n\
+kB 1000, K 1024, MB 1000*1000, M 1024*1024, and so on for G, T, P, E, Z, Y.\n\
 "), stdout);
       printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
     }
@@ -795,6 +771,7 @@ main (int argc, char **argv)
   struct stat *stats IF_LINT (= 0);
   int n_valid_args = 0;
 
+  initialize_main (&argc, &argv);
   program_name = argv[0];
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
@@ -808,7 +785,8 @@ main (int argc, char **argv)
   show_all_fs = 0;
   show_listed_fs = 0;
 
-  human_block_size (getenv ("DF_BLOCK_SIZE"), 0, &output_block_size);
+  human_output_opts = human_options (getenv ("DF_BLOCK_SIZE"), false,
+				     &output_block_size);
 
   print_type = 0;
   posix_format = 0;
@@ -825,24 +803,28 @@ main (int argc, char **argv)
 	  show_all_fs = 1;
 	  break;
 	case 'B':
-	  human_block_size (optarg, 1, &output_block_size);
+	  human_output_opts = human_options (optarg, true, &output_block_size);
 	  break;
 	case 'i':
 	  inode_format = 1;
 	  break;
 	case 'h':
-	  output_block_size = -1024;
+	  human_output_opts = human_autoscale | human_SI | human_base_1024;
+	  output_block_size = 1;
 	  break;
 	case 'H':
-	  output_block_size = -1000;
+	  human_output_opts = human_autoscale | human_SI;
+	  output_block_size = 1;
 	  break;
 	case 'k':
+	  human_output_opts = 0;
 	  output_block_size = 1024;
 	  break;
 	case 'l':
 	  show_local_fs = 1;
 	  break;
 	case 'm': /* obsolescent */
+	  human_output_opts = 0;
 	  output_block_size = 1024 * 1024;
 	  break;
 	case 'T':
@@ -902,27 +884,28 @@ main (int argc, char **argv)
       exit (EXIT_FAILURE);
   }
 
-  {
-    int i;
+  if (optind < argc)
+    {
+      int i;
 
-    /* stat all the given entries to make sure they get automounted,
-       if necessary, before reading the filesystem table.  */
-    stats = (struct stat *)
-      xmalloc ((argc - optind) * sizeof (struct stat));
-    for (i = optind; i < argc; ++i)
-      {
-	if (stat (argv[i], &stats[i - optind]))
-	  {
-	    error (0, errno, "%s", quote (argv[i]));
-	    exit_status = 1;
-	    argv[i] = NULL;
-	  }
-	else
-	  {
-	    ++n_valid_args;
-	  }
-      }
-  }
+      /* stat all the given entries to make sure they get automounted,
+	 if necessary, before reading the filesystem table.  */
+      stats = (struct stat *)
+	xmalloc ((argc - optind) * sizeof (struct stat));
+      for (i = optind; i < argc; ++i)
+	{
+	  if (stat (argv[i], &stats[i - optind]))
+	    {
+	      error (0, errno, "%s", quote (argv[i]));
+	      exit_status = 1;
+	      argv[i] = NULL;
+	    }
+	  else
+	    {
+	      ++n_valid_args;
+	    }
+	}
+    }
 
   mount_list =
     read_filesystem_list ((fs_select_list != NULL
@@ -935,8 +918,8 @@ main (int argc, char **argv)
       /* Couldn't read the table of mounted filesystems.
 	 Fail if df was invoked with no file name arguments;
 	 Otherwise, merely give a warning and proceed.  */
-      const char *warning = (optind == argc ? "" : _("Warning: "));
-      int status = (optind == argc ? 1 : 0);
+      const char *warning = (optind < argc ? _("Warning: ") : "");
+      int status = (optind < argc ? 0 : 1);
       error (status, errno,
 	     _("%scannot read table of mounted filesystems"), warning);
     }
@@ -944,12 +927,7 @@ main (int argc, char **argv)
   if (require_sync)
     sync ();
 
-  if (optind == argc)
-    {
-      print_header ();
-      show_all_entries ();
-    }
-  else
+  if (optind < argc)
     {
       int i;
 
@@ -963,6 +941,11 @@ main (int argc, char **argv)
 	if (argv[i])
 	  show_entry (argv[i], &stats[i - optind]);
     }
+  else
+    {
+      print_header ();
+      show_all_entries ();
+    }
 
   exit (exit_status);
 }
