@@ -43,15 +43,9 @@
 #include <getopt.h>
 #include <sys/types.h>
 
-#include <errno.h>
-#ifndef errno
-extern int errno;
-#endif
-
 #include "system.h"
 #include "error.h"
 #include "long-options.h"
-#include "closeout.h"
 
 /* The official name of this program (e.g., no `g' prefix).  */
 #define PROGRAM_NAME "pathchk"
@@ -163,6 +157,7 @@ main (int argc, char **argv)
   int check_portability = 0;
   int optc;
 
+  initialize_main (&argc, &argv);
   program_name = argv[0];
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
@@ -378,8 +373,8 @@ validate_path (char *path, int portability)
   free (parent);
   if (strlen (path) > (size_t) path_max)
     {
-      error (0, 0, _("path `%s' has length %d; exceeds limit of %ld"),
-	     path, strlen (path), path_max);
+      error (0, 0, _("path `%s' has length %lu; exceeds limit of %ld"),
+	     path, (unsigned long) strlen (path), path_max);
       return 1;
     }
 
