@@ -1,5 +1,5 @@
 /* seq - print sequence of numbers to standard output.
-   Copyright (C) 1994-2002 Free Software Foundation, Inc.
+   Copyright (C) 1994-2003 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 #include <sys/types.h>
 
 #include "system.h"
-#include "closeout.h"
 #include "error.h"
 #include "xstrtol.h"
 #include "xstrtod.h"
@@ -143,8 +142,8 @@ valid_format (const char *fmt)
   if (*fmt == '\0')
     return 0;
 
-  fmt += strspn (fmt, "-+#0");
-  if (ISDIGIT (*fmt))
+  fmt += strspn (fmt, "-+#0 '");
+  if (ISDIGIT (*fmt) || *fmt == '.')
     {
       fmt += strspn (fmt, "0123456789");
 
@@ -339,6 +338,7 @@ main (int argc, char **argv)
   /* The printf(3) format used for output.  */
   char *format_str = NULL;
 
+  initialize_main (&argc, &argv);
   program_name = argv[0];
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
