@@ -1,5 +1,5 @@
 /* tty -- print the path of the terminal connected to standard input
-   Copyright (C) 1990-2002 Free Software Foundation, Inc.
+   Copyright (C) 1990-2003 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include <sys/types.h>
 
 #include "system.h"
-#include "closeout.h"
+#include "exitfail.h"
 #include "error.h"
 
 /* The official name of this program (e.g., no `g' prefix).  */
@@ -78,12 +78,13 @@ main (int argc, char **argv)
   char *tty;
   int optc;
 
+  initialize_main (&argc, &argv);
   program_name = argv[0];
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 
-  close_stdout_set_status (3);
+  exit_failure = 3;
   atexit (close_stdout);
 
   silent = 0;
@@ -108,7 +109,7 @@ main (int argc, char **argv)
 	}
     }
 
-  if (optind != argc)
+  if (optind < argc)
     error (0, 0, _("ignoring all arguments"));
 
   tty = ttyname (0);
